#!/bin/bash
#
# We call back to autogen.sh, but with -x
# to have some more debug

exec bash -ex ./autogen.sh --from=make
